@@ -14,5 +14,5 @@ class GraphManager:
         CreateTrainAndSaveGCN(traindata, testdata, self.save_dataset_path, self.nb_classes)
         print("===== Modèle entrainé et sauvegardé =====")
 
-    def single_prediction(self, saved_model_folder, prediction_dataset_folder, document_to_predict, labels_tab):
-        return predictionsUnique(saved_model_folder, prediction_dataset_folder, document_to_predict, labels_tab)
+    def single_prediction(self, saved_model_folder,document_to_predict_json, labels_tab):
+        return predictionsUnique(saved_model_folder,document_to_predict_json, labels_tab)
