@@ -4,9 +4,9 @@ import numpy as np
 import torch
 
 from graphmanagerlib.Graph import Grapher
-from graphmanagerlib.Data_for_gcn import load_predictionData
+from graphmanagerlib.Data_for_gcn import load_predictionData, getDataForUniquePrediction
 from torch_geometric.utils.convert import from_networkx
-
+from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects
 
 def clearOutputFolder(test_output_fd):
     shutil.rmtree(test_output_fd)
@@ -21,7 +21,9 @@ def make_info(document):
     individual_data = from_networkx(G)
     return G, df, individual_data
 
-def predictionsUnique(saved_model_folder, prediction_dataset_folder, document_to_predict,labels_tab):
+def predictionsUnique(saved_model_folder, document_to_predict_json,labels_tab):
+    prediction_dataset_folder = getDataForUniquePrediction(document_to_predict_json)
+
     predictions_data = load_predictionData(save_fd=prediction_dataset_folder)
 
     model = torch.load(saved_model_folder)
@@ -33,7 +35,12 @@ def predictionsUnique(saved_model_folder, prediction_dataset_folder, document_to
     y_pred = y_preds[sample_indexes]
 
     print("Beginning of the prediction")
-    G, df, individual_data, img = make_info(document_to_predict)
+
+    """
+    OBTENIR LE DOC EN DOC
+    """
+    document = ConvertJsonToDocumentsObjects(document_to_predict_json)[0]
+    _, df, _ , _ = make_info(document)
 
     assert len(y_pred) == df.shape[0]
 
